From 5bd0df23c68a540581c920594745093d71718a15 Mon Sep 17 00:00:00 2001
From: Tarun Mukesh Puvvada <t-puvvada@ti.com>
Date: Tue, 21 Feb 2023 12:03:41 +0530
Subject: [PATCH] GPT Predef Timer value dummy API implemented

Signed-off-by: Tarun Mukesh Puvvada <t-puvvada@ti.com>
---
 mcal_drv/mcal/Gpt/include/Gpt.h | 22 ++++++++++++++++++++++
 mcal_drv/mcal/Gpt/src/Gpt.c     |  9 +++++++++
 2 files changed, 31 insertions(+)

diff --git a/mcal_drv/mcal/Gpt/include/Gpt.h b/mcal_drv/mcal/Gpt/include/Gpt.h
index f0c4072..864031f 100755
--- a/mcal_drv/mcal/Gpt/include/Gpt.h
+++ b/mcal_drv/mcal/Gpt/include/Gpt.h
@@ -333,6 +333,21 @@ typedef enum
     /**< Mode end marker */
 } Gpt_ModeType;
 
+
+/** \brief Type for GPT Predef Timers */
+typedef enum
+{
+   GPT_PREDEF_TIMER_1US_16BIT = 0U,
+   /**< GPT Predef Timer with tick duration 1µs and range 16bit*/
+   GPT_PREDEF_TIMER_1US_24BIT = 1U,
+   /**< GPT Predef Timer with tick duration 1µs and range 24bit*/
+   GPT_PREDEF_TIMER_1US_32BIT = 2U,
+   /**< GPT Predef Timer with tick duration 1µs and range 32bit*/
+   GPT_PREDEF_TIMER_100US_32BIT = 3U
+   /**< GPT Predef Timer with tick duration 100µs and range 32bit*/   
+} Gpt_PredefTimerType;
+
+
 /**
  *  \brief  List of Prescale values for General purpose timer channels
  *          The timer counter is prescaled with the value 2^(PTV+1).
@@ -865,6 +880,13 @@ FUNC(Std_ReturnType, GPT_CODE) Gpt_RegisterReadback(
     P2VAR(Gpt_RegisterReadbackType, AUTOMATIC, GPT_APPL_DATA) RegRbPtr);
 #endif  /* #if (STD_ON == GPT_REGISTER_READBACK_API) */
 
+#if (GPT_PREDEF_TIMER_DISABLED == GPT_PREDEF_TIMER_TYPE)
+/* Function not implemented due to hardware limitation
+   Dummy Function*/
+FUNC(Std_ReturnType, GPT_CODE) Gpt_GetPredefTimerValue (
+     Gpt_PredefTimerType PredefTimer,uint32* TimeValuePtr);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
diff --git a/mcal_drv/mcal/Gpt/src/Gpt.c b/mcal_drv/mcal/Gpt/src/Gpt.c
index 26b65da..caddb8d 100755
--- a/mcal_drv/mcal/Gpt/src/Gpt.c
+++ b/mcal_drv/mcal/Gpt/src/Gpt.c
@@ -1246,6 +1246,15 @@ GPT_FUNC_TEXT_SECTION FUNC(void, GPT_CODE)
 }
 #endif
 
+#if (GPT_PREDEF_TIMER_DISABLED == GPT_PREDEF_TIMER_TYPE)
+FUNC(Std_ReturnType, GPT_CODE) Gpt_GetPredefTimerValue (
+     Gpt_PredefTimerType PredefTimer,uint32* TimeValuePtr)
+{
+    /* Dummy Function*/
+    return E_OK;
+}
+#endif
+
 /* ========================================================================== */
 /*                 Internal Function Declarations                             */
 /* ========================================================================== */
-- 
2.34.1

